#
# spec file for package ghc-dbus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name dbus
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.15
Release:        7.2
Summary:        A client library for the D-Bus IPC system
License:        GPL-3.0-or-later
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-cereal-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-libxml-sax-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-types-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-extra-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
D-Bus is a simple, message-based protocol for inter-process communication,
which allows applications to interact with other parts of the machine and the
user's session using remote procedure calls.

D-Bus is a essential part of the modern Linux desktop, where it replaces
earlier protocols such as CORBA and DCOP.

This library is an implementation of the D-Bus protocol in Haskell. It can be
used to add D-Bus support to Haskell applications, without the awkward
interfaces common to foreign bindings.

Example: connect to the session bus, and get a list of active names.

' &#x7b;-# LANGUAGE OverloadedStrings #-&#x7d;

import Data.List (sort) import DBus import DBus.Client

main = do &#x20; client <- connectSession &#x20; // &#x20; -- Request a list of
connected clients from the bus &#x20; reply <- call_ client (methodCall
"/org/freedesktop/DBus" "org.freedesktop.DBus" "ListNames") &#x20; &#x7b;
methodCallDestination = Just "org.freedesktop.DBus" &#x20; &#x7d; &#x20; //
&#x20; -- org.freedesktop.DBus.ListNames() returns a single value, which is
&#x20; -- a list of names (here represented as [String]) &#x20; let Just names
= fromVariant (methodReturnBody reply !! 0) &#x20; // &#x20; -- Print each name
on a line, sorted so reserved names are below &#x20; -- temporary names.
&#x20; mapM_ putStrLn (sort names) '

>$ ghc --make list-names.hs >$ ./list-names >:1.0 >:1.1 >:1.10 >:1.106 >:1.109
>:1.110 >ca.desrt.dconf >org.freedesktop.DBus >org.freedesktop.Notifications
>org.freedesktop.secrets >org.gnome.ScreenSaver.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license license.txt

%files devel -f %{name}-devel.files
%doc examples

%changelog
* Thu Apr 12 2018 psimons@suse.com
- Update dbus to version 0.10.15.
  A more detailed change log is not available.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.10.13 with cabal2obs.
* Wed Mar 22 2017 psimons@suse.com
- Update to version 0.10.12 revision 1 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.10.12 revision 0 with cabal2obs.
* Sun Jan 17 2016 mimi.vx@gmail.com
- update to 0.10.12
* Mon Oct 12 2015 mimi.vx@gmail.com
- update to 0.10.11
* Fri Apr 24 2015 mimi.vx@gmail.com
- update to 0.10.10
* Sun Feb 15 2015 mimi.vx@gmail.com
- initial commit of dbus package  version 0.10.9.2
